@@ -604,6 +604,9 @@ class MailUtilities {
 			// Conversation
 			//check if exists a conversation for this mail
 			$conv_mail = "";
+			// escape the ids to prevent sql injection
+			$in_reply_to_id = escape_single_quotes($in_reply_to_id);
+			$message_id = escape_single_quotes($message_id);
 			if ($in_reply_to_id != "" && $message_id != "") {
 				$conv_mail = MailContents::instance()->findOne(array("conditions" => "`account_id`=".$account->getId()." AND (`message_id` = '$in_reply_to_id' OR `in_reply_to_id` = '$message_id')"));
 
